---------------------------------------------------
---------------------------------------------------
--connectat com a admsecur
ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS';
ALTER SESSION SET NLS_TIMESTAMP_FORMAT = 'DD/MM/YYYY HH24:MI:SS';
ALTER SESSION SET NLS_TIME_FORMAT = 'HH24:MI:SS';
COMMIT;

---------------------------------------------------
--------------  pais  ------------------------
---------------------------------------------------
--DROP TABLE pais CASCADE CONSTRAINTS PURGE;
CREATE TABLE pais(
      idpais INTEGER 		CONSTRAINT PK_pais	 		PRIMARY KEY
      ,nompais VARCHAR2(50) CONSTRAINT NN_pais_nompais	NOT NULL
							CONSTRAINT UN_pais_nompais 	UNIQUE
      ,dataAlta DATE 		DEFAULT SYSDATE 			NOT NULL
      ,dataBaixa DATE 
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_pais;
CREATE SEQUENCE seq_pais INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idpais_pais
      BEFORE INSERT ON pais
      FOR EACH ROW
BEGIN
      SELECT seq_pais.NEXTVAL INTO :NEW.idpais
      FROM DUAL;
END inserir_idpais_pais;
/
COMMIT;

---------------------------------------------------
--------------  POBLACIO  ------------------------
---------------------------------------------------
--DROP TABLE poblacio CASCADE CONSTRAINTS PURGE;
CREATE TABLE poblacio(
      idpoblacio INTEGER 		CONSTRAINT PK_poblacio	 			PRIMARY KEY
      ,nomPoblacio VARCHAR2(50) CONSTRAINT NN_poblacio_nomPoblacio	NOT NULL
								CONSTRAINT UN_poblacio_nomPoblacio 	UNIQUE
	  ,idpais INTEGER 			CONSTRAINT FK_poblacio 				REFERENCES pais(idpais)
								CONSTRAINT NN_poblacio_idpais 		NOT NULL
      ,dataAlta DATE 			DEFAULT SYSDATE 					NOT NULL
      ,dataBaixa DATE 
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_poblacio;
CREATE SEQUENCE seq_poblacio INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idpoblacio_poblacio
      BEFORE INSERT ON poblacio
      FOR EACH ROW
BEGIN
      SELECT seq_poblacio.NEXTVAL INTO :NEW.idpoblacio
      FROM DUAL;
END inserir_idpoblacio_poblacio;
/
COMMIT;

---------------------------------------------------
-----------------  EMPRESA  -----------------------
---------------------------------------------------
--DROP TABLE empresa CASCADE CONSTRAINTS PURGE;
CREATE TABLE empresa(
      idempresa INTEGER 		CONSTRAINT PK_empresa PRIMARY KEY
      ,nomEmpresa VARCHAR2(50)	CONSTRAINT NN_empresa_nomEmpresa NOT NULL
      ,nif VARCHAR2(50) 		CONSTRAINT NN_empresa_nif NOT NULL
								CONSTRAINT UN_empresa_nif UNIQUE       
      ,adrea VARCHAR2(50) 		CONSTRAINT NN_empresa_adrea NOT NULL
      ,idpoblacio INTEGER 		CONSTRAINT FK_empresa REFERENCES poblacio(idpoblacio)
								CONSTRAINT NN_empresa_idpoblacio NOT NULL
      ,codipostal CHAR(5) 
      ,telefon1 VARCHAR2(15) 	CONSTRAINT NN_empresa_telefon NOT NULL
      ,fax VARCHAR2(15) 
      ,email VARCHAR2(50)
      ,dataAlta DATE 			DEFAULT SYSDATE NOT NULL
      ,dataBaixa DATE      
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_empresa;
CREATE SEQUENCE seq_empresa INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idempresa_empresa
      BEFORE INSERT ON empresa
      FOR EACH ROW
BEGIN
      SELECT seq_empresa.NEXTVAL INTO :NEW.idempresa
      FROM DUAL;
END inserir_idempresa_empresa;
/
COMMIT;


---------------------------------------------------
-----------------  EDIFICI  ------------------------
---------------------------------------------------
--DROP TABLE edifici CASCADE CONSTRAINTS PURGE;
CREATE TABLE edifici(
      idedifici INTEGER CONSTRAINT PK_edifici PRIMARY KEY
      , nomedifici VARCHAR2(50) CONSTRAINT NN_edifici_nomedifici NOT NULL
                                CONSTRAINT UN_edifici_nomedifici UNIQUE
      , idempresa INTEGER 		CONSTRAINT FK_edifici REFERENCES empresa(idempresa)
								CONSTRAINT NN_edifici_idempresa NOT NULL
	  , adrea VARCHAR2(50)  	CONSTRAINT NN_edifici_adrea NOT NULL
      , idpoblacio INTEGER   	CONSTRAINT FK2_edifici REFERENCES poblacio(idpoblacio)
								CONSTRAINT NN_edifici_idpoblacio NOT NULL
      , codipostal CHAR(5)   	CONSTRAINT NN_edifici_codipostal NOT NULL
      , telefon VARCHAR2(15) 	CONSTRAINT NN_edifici_telefon NOT NULL
      , mail VARCHAR2(50)
      , dataAlta DATE 			DEFAULT SYSDATE NOT NULL
      , dataBaixa DATE       
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_edifici;
CREATE SEQUENCE seq_edifici INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idedifici_edifici
      BEFORE INSERT ON edifici
      FOR EACH ROW
BEGIN
      SELECT seq_edifici.NEXTVAL INTO :NEW.idedifici
      FROM DUAL;
END inserir_idedifici_edifici;
/
COMMIT;


---------------------------------------------------
-----------------  departament  ------------------------
---------------------------------------------------
--DROP TABLE departament CASCADE CONSTRAINTS PURGE;
CREATE TABLE departament(
      iddepartament INTEGER 	CONSTRAINT PK_departament PRIMARY KEY
      ,nomdepartament VARCHAR2(50) CONSTRAINT NN_departament_nomdepartament NOT NULL
								--CONSTRAINT UN_departament_nomdepartament UNIQUE
      ,idedifici INTEGER 		CONSTRAINT FK_departament REFERENCES edifici(idedifici)
								CONSTRAINT NN_departament_idempresa NOT NULL
      ,dataAlta DATE 			DEFAULT SYSDATE NOT NULL
      ,dataBaixa DATE       
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_departament;
CREATE SEQUENCE seq_departament INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_iddept_departament
      BEFORE INSERT ON departament
      FOR EACH ROW
BEGIN
      SELECT seq_departament.NEXTVAL INTO :NEW.iddepartament
      FROM DUAL;
END inserir_iddept_departament;
/
COMMIT;


---------------------------------------------------
-----------------  tipusincidencia  ------------------------
---------------------------------------------------
--DROP TABLE tipusinc CASCADE CONSTRAINTS PURGE;
CREATE TABLE tipusinc(
       idtipusinc INTEGER 		CONSTRAINT PK_tipusinc PRIMARY KEY
      ,nomtipusinc VARCHAR2(50) CONSTRAINT NN_tipusinc_nomtipusinc NOT NULL
								CONSTRAINT UN_tipusinc_nomtipusinc UNIQUE
      ,dataAlta DATE 			DEFAULT SYSDATE NOT NULL
      ,dataBaixa DATE       
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_tipusinc;
CREATE SEQUENCE seq_tipusinc INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idtipusinc_tipusinc
      BEFORE INSERT ON tipusinc
      FOR EACH ROW
BEGIN
      SELECT seq_tipusinc.NEXTVAL INTO :NEW.idtipusinc
      FROM DUAL;
END inserir_idtipusinc_tipusinc;
/
COMMIT;

---------------------------------------------------
-----------------  incidencies  --------------------
---------------------------------------------------
--DROP TABLE incidencies CASCADE CONSTRAINTS PURGE;
CREATE TABLE incidencies(
       idincidencia INTEGER 	CONSTRAINT PK_incidencia PRIMARY KEY
      ,idedifici INTEGER 		CONSTRAINT FK1_incidencia REFERENCES edifici(idedifici)
								CONSTRAINT NN_incidencia_idedifici NOT NULL
      ,idtipusinc INTEGER       CONSTRAINT FK2_incidencia REFERENCES tipusinc(idtipusinc)
								CONSTRAINT NN_incidencia_idtipusinc NOT NULL 
      ,iddepartament INTEGER 	CONSTRAINT FK3_incidencia REFERENCES departament(iddepartament)
								CONSTRAINT NN_incidencia_iddepartament NOT NULL 
	  ,descincidencia VARCHAR2(800) CONSTRAINT NN_incidencia_descincidencia NOT NULL
	  ,dataAlta DATE 			DEFAULT SYSDATE NOT NULL
      ,dataBaixa DATE       
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_incidencia;
CREATE SEQUENCE seq_incidencia INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idinc_incidencies
      BEFORE INSERT ON incidencies
      FOR EACH ROW
BEGIN
      SELECT seq_incidencia.NEXTVAL INTO :NEW.idincidencia
      FROM DUAL;
END inserir_idinc_incidencies;
/
COMMIT;

---------------------------------------------------
----------------- permisos ------------------------
---------------------------------------------------
--DROP TABLE permisos CASCADE CONSTRAINTS PURGE;
CREATE TABLE permisos(
       idnivell 	 INTEGER 		
	  ,iddepartament INTEGER 	
	  ,idedifici 	 INTEGER 
	  ,CONSTRAINT PK_permisos PRIMARY KEY (idnivell, iddepartament, idedifici)    
	  ,CONSTRAINT FK1_permisos FOREIGN KEY (iddepartament) REFERENCES departament(iddepartament)
	  ,CONSTRAINT FK2_permisos FOREIGN KEY (idedifici) REFERENCES edifici(idedifici)		  
)
TABLESPACE TBSSECUR;
COMMIT;

---------------------------------------------------
-----------------  personal  ------------------------
---------------------------------------------------
--DROP TABLE personal CASCADE CONSTRAINTS PURGE;
CREATE TABLE personal(
       idpersonal INTEGER 		CONSTRAINT PK_personal PRIMARY KEY
      ,idedifici INTEGER 		CONSTRAINT FK1_personal REFERENCES edifici(idedifici)
								CONSTRAINT NN_personal_idedifici NOT NULL
      ,idempresa INTEGER 		CONSTRAINT FK2_personal REFERENCES empresa(idempresa)
								CONSTRAINT NN_personal_idempresa NOT NULL
      ,iddepartament INTEGER 	CONSTRAINT FK3_personal REFERENCES departament(iddepartament)
								CONSTRAINT NN_personal_iddepartament NOT NULL 
	  ,nif VARCHAR2(9) 			CONSTRAINT NN_personal_nif NOT NULL
								CONSTRAINT UN_personal_nif UNIQUE
	  ,nom VARCHAR2(200)		CONSTRAINT NN_personal_nom NOT NULL
	  ,sexe VARCHAR2(1)   		CONSTRAINT NN_personal_sexe NOT NULL 
	  ,data_naixement DATE 		CONSTRAINT NN_personal_data_naixement NOT NULL
	  ,nivell INTEGER			CONSTRAINT NN_personal_nivell NOT NULL					
	  ,activat VARCHAR2(1)		CONSTRAINT NN_personal_activat NOT NULL
								CONSTRAINT CH_personal_activat CHECK (activat IN ('S','N'))
	  ,dataAlta DATE 			DEFAULT SYSDATE NOT NULL
      ,dataBaixa DATE       
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_personal;
CREATE SEQUENCE seq_personal INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idpersonal_personal
      BEFORE INSERT ON personal
      FOR EACH ROW
BEGIN
      SELECT seq_personal.NEXTVAL INTO :NEW.idpersonal
      FROM DUAL;
END inserir_idpersonal_personal;
/
COMMIT;

---------------------------------------------------
----------------- visitants ------------------------
---------------------------------------------------
--DROP TABLE visitant CASCADE CONSTRAINTS PURGE;
CREATE TABLE visitant(
       idvisitant INTEGER 		CONSTRAINT PK_visitant PRIMARY KEY
	  ,idedifici INTEGER 		CONSTRAINT FK1_visitant REFERENCES edifici(idedifici)
								CONSTRAINT NN_visitant_idedifici NOT NULL
	  ,nif VARCHAR2(9) 			CONSTRAINT NN_visitant_nif NOT NULL
								CONSTRAINT UN_visitant_nif UNIQUE
	  ,nom VARCHAR2(200)		CONSTRAINT NN_visitant_nom NOT NULL
	  ,sexe VARCHAR2(1)   		CONSTRAINT NN_visitant_sexe NOT NULL 
	  ,data_naixement DATE 		CONSTRAINT NN_visitant_data_naixement NOT NULL
	  ,nivell INTEGER			CONSTRAINT NN_visitant_nivell NOT NULL					
	  ,activat VARCHAR2(1)		CONSTRAINT NN_visitant_activat NOT NULL
								CONSTRAINT CH_visitant_activat CHECK (activat IN ('S','N'))
	  ,dataAlta DATE 			DEFAULT SYSDATE NOT NULL
      ,dataBaixa DATE       
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_visitant;
CREATE SEQUENCE seq_visitant INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idvisitant_visitant
      BEFORE INSERT ON visitant
      FOR EACH ROW
BEGIN
      SELECT seq_visitant.NEXTVAL INTO :NEW.idvisitant
      FROM DUAL;
END inserir_idvisitant_visitant;
/
COMMIT;

---------------------------------------------------
----------------- accessos ------------------------
---------------------------------------------------
--DROP TABLE acces CASCADE CONSTRAINTS PURGE;
CREATE TABLE acces(
       idacces INTEGER 		CONSTRAINT PK_acces PRIMARY KEY
	  ,idedifici INTEGER 		CONSTRAINT FK1_acces REFERENCES edifici(idedifici)
								CONSTRAINT NN_acces_idedifici NOT NULL
	  ,iddepartament INTEGER 	CONSTRAINT FK2_acces REFERENCES departament(iddepartament)
								CONSTRAINT NN_acces_iddepartament NOT NULL 
	  ,nif VARCHAR2(9) 			CONSTRAINT NN_acces_nif NOT NULL
	  ,estat VARCHAR2(25)		CONSTRAINT NN_acces_estat NOT NULL
	   CONSTRAINT CH_acces_estat CHECK 
	   (estat IN ('Entrada Acceptada','Sortida Acceptada','Entrada Refusada','Sortida Refusada','Error Lectura'))    
	  ,dataacces DATE 			DEFAULT SYSDATE NOT NULL
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_acces;
CREATE SEQUENCE seq_acces INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idacces_acces
      BEFORE INSERT ON acces
      FOR EACH ROW
BEGIN
      SELECT seq_acces.NEXTVAL INTO :NEW.idacces
      FROM DUAL;
END inserir_idacces_acces;
/
COMMIT;

---------------------------------------------------
----------------- visites------------------------
---------------------------------------------------
--DROP TABLE visites CASCADE CONSTRAINTS PURGE;
CREATE TABLE visites(
       idvisita INTEGER 		CONSTRAINT PK_visites PRIMARY KEY
	  ,idvisitant INTEGER 		CONSTRAINT FK1_visites REFERENCES visitant(idvisitant)
	  							CONSTRAINT NN_visites_idvisitant NOT NULL
	  ,idpersonal INTEGER 		CONSTRAINT FK2_visites REFERENCES personal(idpersonal)
	  							CONSTRAINT NN_visites_idpersonal NOT NULL
	  ,idedifici INTEGER 		CONSTRAINT FK3_visites REFERENCES edifici(idedifici)
								CONSTRAINT NN_visites_idedifici NOT NULL
	  ,iddepartament INTEGER 	CONSTRAINT FK4_visites REFERENCES departament(iddepartament)
	  							CONSTRAINT NN_visites_iddeparatament NOT NULL
	  ,dataAlta DATE 			DEFAULT SYSDATE NOT NULL
      ,dataBaixa DATE       
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_visites;
CREATE SEQUENCE seq_visites INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idvisites_visites
      BEFORE INSERT ON visites
      FOR EACH ROW
BEGIN
      SELECT seq_visites.NEXTVAL INTO :NEW.idvisites
      FROM DUAL;
END inserir_idvisites_visites;
/
COMMIT;

---------------------------------------------------
----------------- paquests ------------------------
---------------------------------------------------
--DROP TABLE paquet CASCADE CONSTRAINTS PURGE;
CREATE TABLE paquet(
       idpaquet INTEGER 		CONSTRAINT PK_paquet PRIMARY KEY
	  ,idedifici INTEGER 		CONSTRAINT FK1_paquet REFERENCES edifici(idedifici)
	  							CONSTRAINT NN_paquet_idedifici NOT NULL
	  ,idpersonal INTEGER 		CONSTRAINT FK2_paquet REFERENCES personal(idpersonal)
	  							CONSTRAINT NN_paquet_idpersonal NOT NULL
	  ,iddepartament INTEGER 	CONSTRAINT FK3_paquet REFERENCES departament(iddepartament)
	  							CONSTRAINT NN_paquet_iddepartament NOT NULL
	  ,observacions VARCHAR2(400) CONSTRAINT NN_paquet_obs NOT NULL
      ,dataAlta DATE 			DEFAULT SYSDATE NOT NULL
      ,dataBaixa DATE       
)
TABLESPACE TBSSECUR;
COMMIT;

--DROP SEQUENCE seq_paquet;
CREATE SEQUENCE seq_paquet INCREMENT BY 1 START WITH 1;
COMMIT;

CREATE OR REPLACE TRIGGER inserir_idpaquet_paquet
      BEFORE INSERT ON paquet
      FOR EACH ROW
BEGIN
      SELECT seq_paquet.NEXTVAL INTO :NEW.idpaquet
      FROM DUAL;
END inserir_idpaquet_paquet;
/
COMMIT;

---------------------------------------------------
------------------  LOGS  -------------------------
---------------------------------------------------
--DROP TABLE admsecur.logs CASCADE CONSTRAINTS PURGE;
CREATE TABLE LOGS(
  	  idlog  INTEGER CONSTRAINT PK_logs PRIMARY KEY
  	  , dataLog      DATE NOT NULL
	  , PROCEDIMENT  VARCHAR2(200)  NOT NULL
	  , PARAMSENTRADA  VARCHAR2(2000) NOT NULL
	  , PARAMSSORTIDA  VARCHAR2(2000) NOT NULL
)
TABLESPACE TBSSECUR;
commit;

--DROP SEQUENCE seq_logs;
CREATE SEQUENCE seq_logs INCREMENT BY 1 START WITH 1;
commit;

CREATE OR REPLACE TRIGGER inserir_idlog_logs
      BEFORE INSERT ON logs
      FOR EACH ROW
BEGIN
      SELECT seq_logs.NEXTVAL INTO :NEW.idlog
      FROM DUAL;
END inserir_idlog_logs;
/
COMMIT;

  







  
  