---------------------------------------------------
---------------------------------------------------
--connectat com a dw_admsecur
ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS';
ALTER SESSION SET NLS_TIMESTAMP_FORMAT = 'DD/MM/YYYY HH24:MI:SS';
ALTER SESSION SET NLS_TIME_FORMAT = 'HH24:MI:SS';
COMMIT;

---------------------------------------------------
----------- DIMENSIONS  ---------------------------
---------------------------------------------------

---------------------------------------------------
---------------------  Anys -----------------------
---------------------------------------------------
--DROP TABLE D_ANY;
CREATE TABLE D_ANY(
        idany 	INTEGER CONSTRAINT PK_d_any PRIMARY KEY
      , descAny CHAR(4)  
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
---------------------  Mesos  ---------------------
---------------------------------------------------
--DROP TABLE D_MESOS;
CREATE TABLE D_MESOS(
        idmes 	INTEGER CONSTRAINT PK_d_mesos PRIMARY KEY
      , descMes VARCHAR2(10)  
	  , idany 	INTEGER CONSTRAINT FK1_d_mesos REFERENCES d_any(idany)
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
-------------------  Dies de la setmana  ----------
---------------------------------------------------
--DROP TABLE D_DIASETMANA;
CREATE TABLE D_DIASETMANA(
        iddia	 INTEGER CONSTRAINT PK_d_diasetmana PRIMARY KEY
      , descDias VARCHAR2(10)  
	  , idmes 	 INTEGER CONSTRAINT FK1_d_diasetmana REFERENCES d_mesos(idmes)
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
-------------------  Trams horaris  ----------
---------------------------------------------------
--DROP TABLE D_TRAMHORARI;
CREATE TABLE D_TRAMHORARI(
        idTramHorari   INTEGER CONSTRAINT PK_d_TramHorari PRIMARY KEY
      , descTramHorari VARCHAR2(15)  
	  , iniciHora 	   INTEGER
	  , fiHora 	       INTEGER
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
-------------------  Trams edat  ----------
---------------------------------------------------
--DROP TABLE D_TRAMEDAT;
CREATE TABLE D_TRAMEDAT(
        idTramEdat     INTEGER CONSTRAINT PK_d_TramEdat PRIMARY KEY
      , descTramEdat   VARCHAR2(15)  
	  , iniciEdat	   INTEGER
	  , fiEdat 	       INTEGER
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
-------------------  Sexe -------------------------
---------------------------------------------------
--DROP TABLE D_SEXE;
CREATE TABLE D_SEXE(
        idSexe    INTEGER CONSTRAINT PK_d_Sexe PRIMARY KEY
      , descSexe  VARCHAR2(15)  
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
-------------------  Departaments  ----------------
---------------------------------------------------
--DROP TABLE D_DEPARTAMENTS;
CREATE TABLE D_DEPARTAMENTS(
        idDepartament   INTEGER CONSTRAINT PK_d_Departament PRIMARY KEY
      , descDepartament VARCHAR2(15)   
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
-------------------  Empresa  ---------------------
---------------------------------------------------
--DROP TABLE D_EMPRESA;
CREATE TABLE D_EMPRESA(
        idEmpresa   INTEGER CONSTRAINT PK_d_Empresa PRIMARY KEY
      , descEmpresa VARCHAR2(15)   
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
-------------------  Edifici ----------------------
---------------------------------------------------
--DROP TABLE D_EDIFICI;
CREATE TABLE D_EDIFICI(
        idEdifici   INTEGER CONSTRAINT PK_d_Edifici PRIMARY KEY
      , descEdifici VARCHAR2(15)   
	  , idEmpresa   CONSTRAINT FK1_F_Edifici REFERENCES d_Empresa(idEmpresa)
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
-------------------  Tipus Indicencia -------------
---------------------------------------------------
--DROP TABLE D_TIPUSINC;
CREATE TABLE D_TIPUSINC(
        idTipusInc    INTEGER CONSTRAINT PK_d_TipusInc PRIMARY KEY
      , descTispusInc VARCHAR2(15)   
)
TABLESPACE DWTBSSECUR;
COMMIT;


---------------------------------------------------
----------- FETS ----------------------------------
---------------------------------------------------

---------------------------------------------------
--------------  Accesos ---------------------------
---------------------------------------------------
--DROP TABLE F_ACCESSOS;
CREATE TABLE F_ACCESSOS(
        idTramHorari  CONSTRAINT FK1_F_accessos REFERENCES d_TramHorari(idTramHorari)
	  , idTramEdat 	  CONSTRAINT FK2_F_accessos REFERENCES d_TramEdat(idTramEdat)
      , idSexe 		  CONSTRAINT FK3_F_accessos REFERENCES d_Sexe(idSexe)
	  , idDepartament CONSTRAINT FK4_F_accessos REFERENCES d_Departaments(idDepartament)
	  , idEdifici 	  CONSTRAINT FK5_F_accessos REFERENCES d_Edifici(idEdifici)
      , idMes		  CONSTRAINT FK6_F_accessos REFERENCES d_Mesos(idMes)
	  , N			  INTEGER
	  , CONSTRAINT PK_F_accessos PRIMARY KEY (idTramHorari,idTramEdat,idSexe,idDepartament,idEdifici)
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
--------------  Visites ---------------------------
---------------------------------------------------
--DROP TABLE F_VISITES;
CREATE TABLE F_VISITES(
        idMes		  CONSTRAINT FK1_F_visites REFERENCES d_Mesos(idMes)
	  , idDepartament CONSTRAINT FK2_F_visites REFERENCES d_Departaments(idDepartament)
	  , idEdifici 	  CONSTRAINT FK3_F_visites REFERENCES d_Edifici(idEdifici)
	  , N			  INTEGER
	  , CONSTRAINT PK_F_visites PRIMARY KEY (idMes,idDepartament,idEdifici)
)
TABLESPACE DWTBSSECUR;
COMMIT;

---------------------------------------------------
--------------  Incidencies -----------------------
---------------------------------------------------
--DROP TABLE F_INCIDENCIES;
CREATE TABLE F_INCIDENCIES(
        idDia		  CONSTRAINT FK1_F_incidencies REFERENCES d_DiaSetmana(idDia)
	  , idDepartament CONSTRAINT FK2_F_incidencies REFERENCES d_Departaments(idDepartament)
	  , idEdifici 	  CONSTRAINT FK3_F_incidencies REFERENCES d_Edifici(idEdifici)
	  , idTipusInc 	  CONSTRAINT FK4_F_incidencies REFERENCES d_TipusInc(idTipusInc)
	  , N			  INTEGER
	  , CONSTRAINT PK_F_incidencies PRIMARY KEY (idMes,idDepartament,idEdifici,idTipusInc)
)
TABLESPACE DWTBSSECUR;
COMMIT;


